%define api     0.5
%define major   0
%define libname %mklibname wireplumber %major
%define girname %mklibname wireplumber-gir %api
%define devname %mklibname wireplumber -d

%bcond_without introspection

Name:       wireplumber
Version:    0.5.8
Release:    %mkrel 1
Summary:    A modular session/policy manager for PipeWire
Group:      Sound/Mixers

License:    MIT
URL:        https://pipewire.pages.freedesktop.org/wireplumber/
Source0:    https://gitlab.freedesktop.org/pipewire/%{name}/-/archive/%{version}/%{name}-%{version}.tar.bz2

## upstream patches

## upstreamable patches

## fedora patches

BuildRequires:  gettext
BuildRequires:  meson
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(libspa-0.2) >= 0.2
BuildRequires:  pkgconfig(libpipewire-0.3) >= 0.3.26
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  python3-lxml
BuildRequires:  python-sphinx
BuildRequires:  doxygen
%{?systemd_ordering}

# Make sure that we have -libs package in the same version
Requires:       %{libname}%{?_isa} = %{version}-%{release}

Provides:       pipewire-session-manager
Conflicts:      pipewire-session-manager

%description
WirePlumber is a modular session/policy manager for PipeWire and a
GObject-based high-level library that wraps PipeWire's API, providing
convenience for writing the daemon's modules as well as external tools for
managing PipeWire.

%package        -n %libname
Summary:        Libraries for WirePlumber clients
Group:          System/Libraries
Recommends:     %{name}%{?_isa} = %{version}-%{release}

%description -n %libname
This package contains the runtime libraries for any application that wishes
to interface with WirePlumber.

%if %with introspection
%package -n     %girname
Summary:        GObject Introspection interface description for WirePlumber
Group:          System/Libraries
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %girname
GObject Introspection interface description for WirePlumber.
%endif

%package        -n %devname
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{name}%{?_isa} = %{version}-%{release}
%if %with introspection
Requires:       %{girname} = %{version}-%{release}
%endif
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description    -n %devname
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
%meson -Dsystem-lua=true \
       -Ddoc=disabled \
       -Dsystemd=enabled \
       -Dsystemd-user-service=true \
%if %with introspection
       -Dintrospection=enabled \
%else
       -Dintrospection=disabled \
%endif
       -Delogind=disabled
%meson_build

%install
%meson_install

# Create local config skeleton
mkdir -p %{buildroot}%{_sysconfdir}/wireplumber/{bluetooth.lua.d,common,main.lua.d,policy.lua.d}

%find_lang %{name}

%posttrans
%systemd_user_post %{name}.service

%preun
%systemd_user_preun %{name}.service

%triggerun -- fedora-release < 35
# When upgrading to Fedora Linux 35, transition to WirePlumber by default
if [ -x "/bin/systemctl" ]; then
    /bin/systemctl --no-reload preset --global %{name}.service || :
fi

%files -f %{name}.lang
%license LICENSE
%doc %{_docdir}/wireplumber/examples/
%{_bindir}/wireplumber
%{_bindir}/wpctl
%{_bindir}/wpexec
%dir %{_sysconfdir}/wireplumber
%dir %{_sysconfdir}/wireplumber/bluetooth.lua.d
%dir %{_sysconfdir}/wireplumber/common
%dir %{_sysconfdir}/wireplumber/main.lua.d
%dir %{_sysconfdir}/wireplumber/policy.lua.d
%{_datadir}/wireplumber/
%{_datadir}/zsh/site-functions/_wpctl
%{_userunitdir}/wireplumber.service
%{_userunitdir}/wireplumber@.service

%files -n %libname
%license LICENSE
%dir %{_libdir}/wireplumber-%{api}/
%{_libdir}/wireplumber-%{api}/libwireplumber-*.so
%{_libdir}/libwireplumber-%{api}.so.%{major}{,.*}

%if %with introspection
%files -n %girname
%license LICENSE
%{_libdir}/girepository-1.0/Wp-%{api}.typelib
%endif

%files -n %devname
%{_includedir}/wireplumber-%{api}/
%{_libdir}/libwireplumber-%{api}.so
%{_libdir}/pkgconfig/wireplumber-%{api}.pc
%if %with introspection
%{_datadir}/gir-1.0/Wp-%{api}.gir
%endif


%changelog
* Sat Feb 08 2025 daviddavid <daviddavid> 0.5.8-1.mga10
+ Revision: 2146090
- new version: 0.5.8

* Tue Dec 17 2024 daviddavid <daviddavid> 0.5.7-1.mga10
+ Revision: 2125811
- new version: 0.5.7

* Sun Sep 22 2024 daviddavid <daviddavid> 0.5.6-1.mga10
+ Revision: 2100118
- new version: 0.5.6

* Fri Jun 28 2024 daviddavid <daviddavid> 0.5.5-1.mga10
+ Revision: 2077917
- new version: 0.5.5

* Wed Jun 26 2024 daviddavid <daviddavid> 0.5.4-1.mga10
+ Revision: 2077130
- new version: 0.5.4

* Sat Jun 01 2024 daviddavid <daviddavid> 0.5.3-1.mga10
+ Revision: 2069127
- new version: 0.5.3

* Wed Apr 24 2024 daviddavid <daviddavid> 0.5.2-1.mga10
+ Revision: 2060837
- new version: 0.5.2

* Tue Apr 02 2024 daviddavid <daviddavid> 0.5.1-1.mga10
+ Revision: 2053893
- new version 0.5.1

* Sat Mar 23 2024 daviddavid <daviddavid> 0.5.0-1.mga10
+ Revision: 2051457
- new version: 0.5.0

* Tue Dec 05 2023 daviddavid <daviddavid> 0.4.17-1.mga10
+ Revision: 2013425
- new version: 0.4.17

* Thu Nov 30 2023 daviddavid <daviddavid> 0.4.16-1.mga10
+ Revision: 2011523
- new version: 0.4.16

* Sun Oct 22 2023 daviddavid <daviddavid> 0.4.15-1.mga10
+ Revision: 2000266
- new version: 0.4.15

* Sat Mar 11 2023 ghibo <ghibo> 0.4.14-1.mga9
+ Revision: 1948597
- Fix typo in Conflicts.
- Update to release 0.4.14.

* Fri Jan 27 2023 daviddavid <daviddavid> 0.4.13-2.mga9
+ Revision: 1936454
- split out in a separate pkg the gobject introspection lib

* Wed Dec 14 2022 tv <tv> 0.4.13-1.mga9
+ Revision: 1922057
- wireplumber 0.4.13

* Wed Oct 12 2022 tv <tv> 0.4.12-2.mga9
+ Revision: 1896542
- wireplumber 0.4.12

* Sun Aug 28 2022 tv <tv> 0.4.11-2.mga9
+ Revision: 1881419
- Add two patches to fix a rescan loop with Bluetooth

* Tue Jul 19 2022 tv <tv> 0.4.11-1.1.mga9
+ Revision: 1869375
- Package translations
- wireplumber 0.4.11
- Add patch to avoid crashes in VM
- Add patch to avoid dbus crash
- wireplumber 0.4.10

* Wed Mar 23 2022 tv <tv> 0.4.9-1.mga9
+ Revision: 1821620
- wireplumber 0.4.9

* Thu Mar 17 2022 tv <tv> 0.4.8-3.mga9
+ Revision: 1797052
- Backport e429db7e8c266045aee25e153fb2308bd61fe233 to fix sound on aarch64

* Mon Mar 07 2022 tv <tv> 0.4.8-2.mga9
+ Revision: 1789486
- Add patch to fix openal and WINE format negotiation.
- wireplumber 0.4.8

* Wed Jan 19 2022 tv <tv> 0.4.7-2.mga9
+ Revision: 1769021
- wireplumber 0.4.7
- Add patch to fix default device.

* Sun Jan 09 2022 tv <tv> 0.4.6-2.mga9
+ Revision: 1767412
+ rebuild (emptylog)

* Sun Jan 09 2022 tv <tv> 0.4.6-1.mga9
+ Revision: 1767392
- Disable introspection for good after latest test
- Disable introspection for now because of failures:
  "FAILED: docs/Wp-0.4.gir
  input buffer overflow, can't enlarge buffer because scanner uses REJECT
  ninja: build stopped: subcommand failed."
- wireplumber 0.4.6
- imported package wireplumber


* Sun Jan 09 2022 Thierry Vignaud <tv@mageia.org> 
- Initial import from FC

* Fri Nov 19 2021 Wim Taymans <wim.taymans@redhat.com> - 0.4.5-3
- Add some upstream patches for OBS audio output capture and
  device switching.

* Wed Nov 17 2021 Peter Hutterer <peter.hutterer@redhat.com> - 0.4.5-2
- Move the systemd scriptlet to posttrans so we can dnf swap with
  media-session (#2022584)

* Thu Nov 11 2021 Wim Taymans <wim.taymans@redhat.com> - 0.4.5-1
- wireplumber 0.4.5

* Tue Nov 02 2021 Neal Gompa <ngompa@fedoraproject.org> - 0.4.4-3
- Try again for WirePlumber preset upgrades to F35+ (#2016253)

* Sun Oct 24 2021 Neal Gompa <ngompa@fedoraproject.org> - 0.4.4-2
- Ensure WirePlumber activates on upgrade to F35+ (#2016253)

* Fri Oct 15 2021 Wim Taymans <wim.taymans@redhat.com> - 0.4.4-1
- wireplumber 0.4.4

* Wed Oct 13 2021 Neal Gompa <ngompa@fedoraproject.org> - 0.4.3-3
- Fix config setup in file list (#2013861)

* Mon Oct 11 2021 Peter Hutterer <peter.hutterer@redhat.com> - 0.4.3-2
- Fix segfault due to a typo (#2012606)

* Fri Oct 08 2021 Wim Taymans <wim.taymans@redhat.com> - 0.4.3-1
- wireplumber 0.4.3

* Wed Sep 01 2021 Peter Hutterer <peter.hutterer@redhat.com> - 0.4.2-1
- wireplumber 0.4.2

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jul 06 2021 Peter Hutterer <peter.hutterer@redhat.com> 0.4.1-1
- Initial package (#1976012)
